## mini-youtube-player

**Search and play videos on youtube in cli**

Main features:
*  Search for Videos or Playlists on youtube
*  View the search results
*  Play a video or only listen to audio
*  View a history of recently played videos
*  Download audio or video file from search results

That's it. mini-youtube-player is not intended to have many features.  
Instead it is intended to be simple and just work. (hopefully)

mini-youtube-player uses https://github.com/alexmercerind/youtube-search-python -- thanks for the great work!

Have fun.
Don't do stuff you are not allowed to do.

### Installation

```sh
$ pip install mini-youtube-player
```

### Usage example

```sh
$ mini-youtube-player
```

### Release History

* 1.0.3
    * First version published.

### Meta

Distributed under the MIT license.
